##  1. Why should I use the SAP LeanIX Portal?
The SAP LeanIX Portal extends users a way to link EA data to approve/quality assure new software orders and contextualize technical support tickets. This portal offers SAP LeanIX users more opportunities to troubleshoot problems autonomously, and can be configured by admins quickly and with a variety of filters.
